import { LanguageCode, Widget, RemotePackageUrlInfo, IWidgetOptions } from '@widget-js/core';

interface Pageable {
    page: number;
    pageSize: number;
}
interface Pagination<T> {
    total: number;
    page: number;
    totalPage: number;
    pageSize: number;
    data: T[];
}

/**
 * -1：reject
 * 0：reviewing
 * 1：pass
 */
type ReviewStatus = -1 | 0 | 1;
interface WidgetSearchOptions extends Pageable {
    keyword?: string;
    language?: LanguageCode;
    packageKeyword?: string;
    checkMicrosoftStoreReview?: boolean;
    category?: string;
    packageName?: string;
    name?: string;
    reviewStatus: ReviewStatus;
    appVersion?: string;
}
declare class WebWidget extends Widget {
    createTime: Date;
    updateTime: Date;
    package?: {
        version: string;
        remote?: RemotePackageUrlInfo;
    };
    constructor(options: IWidgetOptions);
    /**
     * 是否支持悬浮窗
     */
    isSupportOverlap(): boolean;
    isSupportBackground(): boolean;
    /**
     * 是否支持普通模式
     */
    isSupportNormal(): boolean;
    isConfigurable(): boolean;
    static fromJSON(json: string): WebWidget;
    static fromObject(obj: any): WebWidget;
    /**
     * 获取组件标题
     * @param lang 语言环境，不传则获取默认语言
     */
    getTitle(lang?: LanguageCode): string | undefined;
    /**
     * 获取组件描述
     * @param lang 语言环境，不传则获取默认标题
     */
    getDescription(lang?: LanguageCode): string | undefined;
    getPackageJsonUrl(): string | undefined;
}

interface IResponse<T = any> {
    code: number;
    msg: string;
    data?: T;
}
type FailResponse = Omit<IResponse, 'data'>;
declare class R {
    static ok<T = any>(data?: T): IResponse<T>;
    static fail(fail: string | FailResponse): IResponse;
}

export { IResponse, Pageable, Pagination, R, ReviewStatus, WebWidget, WidgetSearchOptions };
